==> apache-camel-3.18.3-src.zip: apache-camel-3.18.3/components/camel-kubernetes/src/test/java/org/apache/camel/component/kubernetes/cloud/ServiceCallClientRouteManualTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.kubernetes.cloud;

import org.apache.camel.RoutesBuilder;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.kubernetes.KubernetesConfiguration;
import org.apache.camel.model.cloud.ServiceCallConfigurationDefinition;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

@Disabled("Manual test")
public class ServiceCallClientRouteManualTest extends CamelTestSupport {

    @Test
    public void testServiceCall() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(1);

        template.sendBody("direct:start", "Hello World");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RoutesBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                KubernetesConfiguration kubernetesConfiguration = new KubernetesConfiguration();
                kubernetesConfiguration.setMasterUrl("http://172.28.128.80:8080");
                kubernetesConfiguration.setUsername("admin");
                kubernetesConfiguration.setPassword("admin");
                kubernetesConfiguration.setNamespace("default");

                ServiceCallConfigurationDefinition config = new ServiceCallConfigurationDefinition();
                config.setServiceDiscovery(new KubernetesEnvServiceDiscovery(kubernetesConfiguration));

                // register configuration
                context.setServiceCallConfiguration(config);

                from("direct:start").serviceCall("cdi-camel-jetty").serviceCall("cdi-camel-jetty").to("mock:result");
            }
        };
    }
}

==> apache-camel-4.10.9-src.zip: apache-camel-4.10.9/components/camel-kubernetes/src/test/java/org/apache/camel/component/kubernetes/cloud/ServiceCallClientRouteManualTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.kubernetes.cloud;

import org.apache.camel.RoutesBuilder;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.kubernetes.KubernetesConfiguration;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.model.cloud.ServiceCallConfigurationDefinition;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;

@Disabled("Manual test")
public class ServiceCallClientRouteManualTest extends CamelTestSupport {

    @Test
    public void testServiceCall() throws Exception {
        getMockEndpoint("mock:result").expectedMessageCount(1);

        template.sendBody("direct:start", "Hello World");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected RoutesBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                KubernetesConfiguration kubernetesConfiguration = new KubernetesConfiguration();
                kubernetesConfiguration.setMasterUrl("http://172.28.128.80:8080");
                kubernetesConfiguration.setUsername("admin");
                kubernetesConfiguration.setPassword("admin");
                kubernetesConfiguration.setNamespace("default");

                ServiceCallConfigurationDefinition config = new ServiceCallConfigurationDefinition();
                config.setServiceDiscovery(new KubernetesEnvServiceDiscovery(kubernetesConfiguration));

                // register configuration
                context.setServiceCallConfiguration(config);

                from("direct:start").serviceCall("cdi-camel-jetty").serviceCall("cdi-camel-jetty").to("mock:result");
            }
        };
    }
}
